[vlc-commits] commit: Moved vout_IntfInit out of vlc_vout.h (Laurent Aimar )

git at videolan.org git at videolan.org
Sun Apr 18 15:03:16 CEST 2010


vlc | branch: master | Laurent Aimar <fenrir at videolan.org> | Sun Apr 18 03:25:28 2010 +0200| [447d0c8fad511536e86bad5141bd9dd9721ed95a] | committer: Laurent Aimar 

Moved vout_IntfInit out of vlc_vout.h

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=447d0c8fad511536e86bad5141bd9dd9721ed95a
---

 include/vlc_vout.h               |    1 -
 src/video_output/vout_internal.h |    3 ++-
 2 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/include/vlc_vout.h b/include/vlc_vout.h
index fa180b4..e501d1e 100644
--- a/include/vlc_vout.h
+++ b/include/vlc_vout.h
@@ -282,7 +282,6 @@ VLC_EXPORT( void,            vout_UnlinkPicture,  ( vout_thread_t *, picture_t *
  */
 VLC_EXPORT( spu_t *, vout_GetSpu, ( vout_thread_t * ) );
 
-void vout_IntfInit( vout_thread_t * );
 VLC_EXPORT( void, vout_EnableFilter, ( vout_thread_t *, const char *,bool , bool  ) );
 
 /**@}*/
diff --git a/src/video_output/vout_internal.h b/src/video_output/vout_internal.h
index 820bfbb..466f2cc 100644
--- a/src/video_output/vout_internal.h
+++ b/src/video_output/vout_internal.h
@@ -102,10 +102,11 @@ struct vout_thread_sys_t
     vlc_mouse_t     mouse;
 };
 
 /* DO NOT use vout_RenderPicture unless you are in src/video_ouput */
 picture_t *vout_RenderPicture( vout_thread_t *, picture_t *,
                                subpicture_t *,
                                mtime_t render_date );
+void vout_IntfInit( vout_thread_t * );
 
 /* DO NOT use vout_UsePictureLocked unless you are in src/video_ouput
  *
@@ -102,10 +102,11 @@ struct vout_thread_sys_t
 };
 
-/* DO NOT use vout_RenderPicture unless you are in src/video_ouput */
+/* DO NOT use vout_RenderPicture/vout_IntfInit unless you are in src/video_ouput */
 picture_t *vout_RenderPicture( vout_thread_t *, picture_t *,
                                subpicture_t *,



More information about the vlc-commits mailing list